===============================
WinFSPy
===============================

.. image:: https://ci.appveyor.com/api/projects/status/jg07bt75a9r78ou4/branch/master?svg=true
        :target: https://ci.appveyor.com/project/touilleMan/winfspy/branch/master
        :alt: Appveyor CI Status

.. image:: https://img.shields.io/pypi/v/winfspy.svg
        :target: https://pypi.python.org/pypi/winfspy
        :alt: Pypi Status

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
        :target: https://github.com/ambv/black
        :alt: Code style: black

Bindings for `WinFSP <http://www.secfs.net/winfsp/>`_

* Free software: BSD
